@@ -14,6 +14,7 @@ from protocolinterface import ProtocolInterface, val
 from jobqueues.simqueue import SimQueue, QueueJobStatus, _inProgressStatus
 from jobqueues.util import ensurelist
 import getpass
+import unittest
 import logging
 
 logger = logging.getLogger(__name__)
@@ -247,7 +248,7 @@ class SlurmQueue(SimQueue, ProtocolInterface):
             self._qinfo = SlurmQueue._find_binary("sinfo")
             self._qcancel = SlurmQueue._find_binary("scancel")
             self._qstatus = SlurmQueue._find_binary("squeue")
-            self._qjobinfo = SlurmQueue._find_binary("sacct")
+            self._qjobinfo = SlurmQueue._find_binary("sacct", permissive=True)
             self._checkQueue()
 
     def _checkQueue(self):
@@ -261,23 +262,22 @@ class SlurmQueue(SimQueue, ProtocolInterface):
         except Exception as e:
             raise RuntimeError(f"SLURM squeue command failed with error: {e}")
 
-        try:
-            ret = check_output([self._qjobinfo]).decode("ascii")
-            if "Slurm accounting storage is disabled" in ret:
-                raise RuntimeError(
-                    "Slurm accounting is disabled. Cannot get detailed job info."
-                )
-        except CalledProcessError as e:
-            raise RuntimeError(
-                f"SLURM sacct command failed with error: {e} and errorcode: {e.returncode}"
-            )
-        except Exception as e:
-            raise RuntimeError(f"SLURM sacct command failed with error: {e}")
+        if self._qjobinfo is not None:
+            try:
+                ret = check_output([self._qjobinfo]).decode("ascii")
+                if "Slurm accounting storage is disabled" in ret:
+                    raise RuntimeError(
+                        "Slurm accounting is disabled. Cannot get detailed job info."
+                    )
+            except Exception as e:
+                print(f"SLURM sacct command failed with error: {e}")
 
     @staticmethod
-    def _find_binary(binary):
+    def _find_binary(binary, permissive=False):
         ret = shutil.which(binary, mode=os.X_OK)
         if not ret:
+            if permissive:
+                return None
             raise FileNotFoundError(
                 "Could not find required executable [{}]".format(binary)
             )
@@ -387,7 +387,7 @@ class SlurmQueue(SimQueue, ProtocolInterface):
             except CalledProcessError as e:
                 logger.error(e.output)
                 raise
-            except:
+            except Exception:
                 raise
 
     def _robust_check_output(self, cmd, maxtries=3):
@@ -415,8 +415,6 @@ class SlurmQueue(SimQueue, ProtocolInterface):
         total : int
             Total running and queued workunits
         """
-        import time
-
         if self.jobname is None:
             raise ValueError("The jobname needs to be defined.")
 
@@ -439,20 +437,21 @@ class SlurmQueue(SimQueue, ProtocolInterface):
         inprog = max(0, len(lines) - 1)
 
         # Check also with sacct because squeue sometimes fails to report the right number
-        try:
-            res = self.jobInfo()
-            if res is None:
-                return inprog
-            info = [
-                key for key, val in res.items() if val["state"] in _inProgressStatus
-            ]
-            if len(info) != inprog:
-                logger.warning(
-                    f"squeue and sacct gave different number of running jobs ({inprog}/{len(info)}) with name {self.jobname}. Using the max of the two."
-                )
-            inprog = max(inprog, len(info))
-        except Exception as e:
-            logger.warning(f"Failed to get jobInfo with error: {e}")
+        if self._qjobinfo is not None:
+            try:
+                res = self.jobInfo()
+                if res is None:
+                    return inprog
+                info = [
+                    key for key, val in res.items() if val["state"] in _inProgressStatus
+                ]
+                if len(info) != inprog:
+                    logger.warning(
+                        f"squeue and sacct gave different number of running jobs ({inprog}/{len(info)}) with name {self.jobname}. Using the max of the two."
+                    )
+                inprog = max(inprog, len(info))
+            except Exception as e:
+                logger.warning(f"Failed to get jobInfo with error: {e}")
 
         return inprog
 
@@ -474,8 +473,6 @@ class SlurmQueue(SimQueue, ProtocolInterface):
             logger.debug(ret.decode("ascii"))
 
     def jobInfo(self):
-        from jobqueues.simqueue import QueueJobStatus
-
         if self.jobname is None:
             raise ValueError("The jobname needs to be defined.")
 
@@ -548,9 +545,6 @@ class SlurmQueue(SimQueue, ProtocolInterface):
         self.memory = value
 
 
-import unittest
-
-
 class _TestSlurmQueue(unittest.TestCase):
     def test_config(self):
         from jobqueues.home import home
